#
# spec file for package powerd
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%if %{undefined systemd_requires}
%global         with_sysvinit 1
%endif
%bcond_with     sysvinit

Name:           powerd
Version:        2.0.2
Release:        100.5
Summary:        UPS monitoring daemon
License:        GPL-2.0+
Group:          System/Base
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?suse_version} > 1140
%if 0%{?suse_version} > 1230
BuildRequires:  systemd-rpm-macros
%else
BuildRequires:  pkg-config
BuildRequires:  systemd-devel
%endif
%endif
Url:            https://power.sourceforge.net/
Source0:        powerd-%{version}.tar.bz2
Source1:        rc.powerd
Source2:        powerd.service
Patch0:         powerd-%{version}.dif
Patch1:         powerd-%{version}-getaddrinfo.patch
%if %{without sysvinit}
%if %{undefined _unitdir}
%{expand: %%global %_unitdir %(pkg-config systemd --variable=systemdsystemunitdir)}
%endif
%endif

%description -n powerd
powerd monitors the serial port connected to an UPS device and will perform
an unattended shutdown of the system if the UPS is on battery longer
than a specified number of minutes.

%prep
%setup -q
%patch0
%patch1
%_fixowner .
%_fixgroup .
/bin/chmod -Rf a+rX,g-w,o-w .

%build
  RPM_OPT_FLAGS="${RPM_OPT_FLAGS} $(getconf LFS_CFLAGS) -pipe"
  CC=%__cc
  export RPM_OPT_FLAGS CC
  %configure --prefix= --bindir='$(DESTDIR)/sbin' \
	--mandir='$(DESTDIR)%{_mandir}' \
	--sbindir='$(DESTDIR)/sbin'
  make %{?_smp_mflags} CFLAGS="-I. $RPM_OPT_FLAGS -DWITH_SYSVINIT"

%install
  mkdir -m 755 -p %{buildroot}/etc
  mkdir -m 755 -p %{buildroot}/sbin
  mkdir -m 755 -p %{buildroot}%{_sbindir}
  mkdir -m 755 -p %{buildroot}%{_mandir}/man8
  make install DESTDIR=%{buildroot}
  echo '# ' > %{buildroot}/etc/powerd.conf
  echo '# /etc/powerd.conf  for powerd version-%{version}' >> %{buildroot}/etc/powerd.conf
  echo '# ' >> %{buildroot}/etc/powerd.conf
  echo '# read manual page of detectups(8) and powerd(8) its self.' >> %{buildroot}/etc/powerd.conf
  echo '# ' >> %{buildroot}/etc/powerd.conf
  echo '# to enable powerd service run the command' >> %{buildroot}/etc/powerd.conf
%if %{with sysvinit}
  echo '#    insserv powerd' >> %{buildroot}/etc/powerd.conf
  echo '#    rcpowerd start' >> %{buildroot}/etc/powerd.conf
  mkdir -p %{buildroot}/etc/init.d
  install -m 0744 %{S:1} %{buildroot}/etc/init.d/powerd
  ln -sf /etc/init.d/powerd %{buildroot}%{_sbindir}/rcpowerd
%else
  echo '#    systemctl enable powerd.service' >> %{buildroot}/etc/powerd.conf
  echo '#    systemctl start  powerd.service' >> %{buildroot}/etc/powerd.conf
  mkdir -p %{buildroot}/%{_unitdir}
  install -m 0644 %{S:2} %{buildroot}/%{_unitdir}/powerd.service
  ln -sf %{_sbindir}/service %{buildroot}%{_sbindir}/rcpowerd
%endif

%preun
%stop_on_removal powerd

%postun
%restart_on_update powerd
%if %{with sysvinit}
%insserv_cleanup
%endif

%files -n powerd
%defattr (-,root,root,755)
%doc README COPYING SUPPORTED FAQ powerd.conf.monitor powerd.conf.peer
/sbin/powerd
/sbin/detectups
%{_sbindir}/rcpowerd
%config /etc/powerd.conf
%if %{with sysvinit}
%config /etc/init.d/powerd
%else
%attr(0644,root,root) %{_unitdir}/powerd.service
%endif
%doc %{_mandir}/man8/powerd.8.gz
%doc %{_mandir}/man8/detectups.8.gz

%changelog
* Thu Aug 21 2014 lnussel@suse.de
- use systemd-rpm-macros instead of systemd-devel to avoid build
  dependency on systemd and it's deps in turn
- install rcpowerd link also when using systemd
* Thu Mar 13 2014 werner@suse.de
- Now work with latest systemd
* Wed Jan 15 2014 werner@suse.de
- Correct version number in configuration file
* Tue Jan 14 2014 werner@suse.de
- Split off powerd from sysvinit
- Support systemd unit file
